@@ -33,7 +33,7 @@ var searchData=
   ['filteroptionsrequest_30',['FilterOptionsRequest',['../exceptioncom_1_1sun_1_1star_1_1document_1_1FilterOptionsRequest.html',1,'com::sun::star::document']]],
   ['finishengineevent_31',['FinishEngineEvent',['../structcom_1_1sun_1_1star_1_1script_1_1FinishEngineEvent.html',1,'com::sun::star::script']]],
   ['fixedline_32',['FixedLine',['../servicecom_1_1sun_1_1star_1_1report_1_1FixedLine.html',1,'com::sun::star::report']]],
-  ['fixedtext_33',['fixedtext',['../servicecom_1_1sun_1_1star_1_1report_1_1FixedText.html',1,'FixedText'],['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1FixedText.html',1,'FixedText']]],
+  ['fixedtext_33',['FixedText',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1FixedText.html',1,'FixedText'],['../servicecom_1_1sun_1_1star_1_1report_1_1FixedText.html',1,'FixedText']]],
   ['flatconnectionproperties_34',['FLATConnectionProperties',['../servicecom_1_1sun_1_1star_1_1sdbc_1_1FLATConnectionProperties.html',1,'com::sun::star::sdbc']]],
   ['floatingpointbitmaplayout_35',['FloatingPointBitmapLayout',['../structcom_1_1sun_1_1star_1_1rendering_1_1FloatingPointBitmapLayout.html',1,'com::sun::star::rendering']]],
   ['focusevent_36',['FocusEvent',['../structcom_1_1sun_1_1star_1_1awt_1_1FocusEvent.html',1,'com::sun::star::awt']]],
@@ -45,42 +45,43 @@ var searchData=
   ['fontinfo_42',['FontInfo',['../structcom_1_1sun_1_1star_1_1rendering_1_1FontInfo.html',1,'com::sun::star::rendering']]],
   ['fontmetrics_43',['FontMetrics',['../structcom_1_1sun_1_1star_1_1rendering_1_1FontMetrics.html',1,'com::sun::star::rendering']]],
   ['fontrequest_44',['FontRequest',['../structcom_1_1sun_1_1star_1_1rendering_1_1FontRequest.html',1,'com::sun::star::rendering']]],
-  ['footer_45',['Footer',['../servicecom_1_1sun_1_1star_1_1presentation_1_1textfield_1_1Footer.html',1,'com::sun::star::presentation::textfield']]],
-  ['footershape_46',['FooterShape',['../servicecom_1_1sun_1_1star_1_1presentation_1_1FooterShape.html',1,'com::sun::star::presentation']]],
-  ['footnote_47',['Footnote',['../servicecom_1_1sun_1_1star_1_1text_1_1Footnote.html',1,'com::sun::star::text']]],
-  ['footnotes_48',['Footnotes',['../servicecom_1_1sun_1_1star_1_1text_1_1Footnotes.html',1,'com::sun::star::text']]],
-  ['footnotesettings_49',['FootnoteSettings',['../servicecom_1_1sun_1_1star_1_1text_1_1FootnoteSettings.html',1,'com::sun::star::text']]],
-  ['forbiddencharacters_50',['ForbiddenCharacters',['../structcom_1_1sun_1_1star_1_1i18n_1_1ForbiddenCharacters.html',1,'com::sun::star::i18n']]],
-  ['form_51',['Form',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1Form.html',1,'com::sun::star::form::component']]],
-  ['formatcondition_52',['FormatCondition',['../servicecom_1_1sun_1_1star_1_1report_1_1FormatCondition.html',1,'com::sun::star::report']]],
-  ['formatelement_53',['FormatElement',['../structcom_1_1sun_1_1star_1_1i18n_1_1FormatElement.html',1,'com::sun::star::i18n']]],
-  ['formattedfield_54',['formattedfield',['../servicecom_1_1sun_1_1star_1_1report_1_1FormattedField.html',1,'FormattedField'],['../servicecom_1_1sun_1_1star_1_1form_1_1control_1_1FormattedField.html',1,'FormattedField'],['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1FormattedField.html',1,'FormattedField']]],
-  ['formattedstring_55',['FormattedString',['../servicecom_1_1sun_1_1star_1_1chart2_1_1FormattedString.html',1,'com::sun::star::chart2']]],
-  ['formcomponent_56',['FormComponent',['../servicecom_1_1sun_1_1star_1_1form_1_1FormComponent.html',1,'com::sun::star::form']]],
-  ['formcomponentpropertyhandler_57',['FormComponentPropertyHandler',['../servicecom_1_1sun_1_1star_1_1form_1_1inspection_1_1FormComponentPropertyHandler.html',1,'com::sun::star::form::inspection']]],
-  ['formcomponents_58',['FormComponents',['../servicecom_1_1sun_1_1star_1_1form_1_1FormComponents.html',1,'com::sun::star::form']]],
-  ['formcontroller_59',['formcontroller',['../servicecom_1_1sun_1_1star_1_1form_1_1FormController.html',1,'FormController'],['../servicecom_1_1sun_1_1star_1_1form_1_1runtime_1_1FormController.html',1,'FormController']]],
-  ['formcontrollerdispatcher_60',['FormControllerDispatcher',['../servicecom_1_1sun_1_1star_1_1form_1_1FormControllerDispatcher.html',1,'com::sun::star::form']]],
-  ['formcontrolmodel_61',['FormControlModel',['../servicecom_1_1sun_1_1star_1_1form_1_1FormControlModel.html',1,'com::sun::star::form']]],
-  ['formoperations_62',['FormOperations',['../servicecom_1_1sun_1_1star_1_1form_1_1runtime_1_1FormOperations.html',1,'com::sun::star::form::runtime']]],
-  ['forms_63',['forms',['../servicecom_1_1sun_1_1star_1_1sdb_1_1Forms.html',1,'Forms'],['../servicecom_1_1sun_1_1star_1_1form_1_1Forms.html',1,'Forms']]],
-  ['formulaopcodemapentry_64',['FormulaOpCodeMapEntry',['../structcom_1_1sun_1_1star_1_1sheet_1_1FormulaOpCodeMapEntry.html',1,'com::sun::star::sheet']]],
-  ['formulaopcodemapper_65',['FormulaOpCodeMapper',['../servicecom_1_1sun_1_1star_1_1sheet_1_1FormulaOpCodeMapper.html',1,'com::sun::star::sheet']]],
-  ['formulaparser_66',['FormulaParser',['../servicecom_1_1sun_1_1star_1_1sheet_1_1FormulaParser.html',1,'com::sun::star::sheet']]],
-  ['formulaproperties_67',['FormulaProperties',['../servicecom_1_1sun_1_1star_1_1formula_1_1FormulaProperties.html',1,'com::sun::star::formula']]],
-  ['formulatoken_68',['FormulaToken',['../structcom_1_1sun_1_1star_1_1sheet_1_1FormulaToken.html',1,'com::sun::star::sheet']]],
-  ['frame_69',['Frame',['../servicecom_1_1sun_1_1star_1_1frame_1_1Frame.html',1,'com::sun::star::frame']]],
-  ['frameactionevent_70',['FrameActionEvent',['../structcom_1_1sun_1_1star_1_1frame_1_1FrameActionEvent.html',1,'com::sun::star::frame']]],
-  ['framecontrol_71',['FrameControl',['../servicecom_1_1sun_1_1star_1_1frame_1_1FrameControl.html',1,'com::sun::star::frame']]],
-  ['frameloader_72',['FrameLoader',['../servicecom_1_1sun_1_1star_1_1frame_1_1FrameLoader.html',1,'com::sun::star::frame']]],
-  ['frameloaderfactory_73',['FrameLoaderFactory',['../servicecom_1_1sun_1_1star_1_1frame_1_1FrameLoaderFactory.html',1,'com::sun::star::frame']]],
-  ['framescontainer_74',['FramesContainer',['../servicecom_1_1sun_1_1star_1_1frame_1_1FramesContainer.html',1,'com::sun::star::frame']]],
-  ['ftpcontent_75',['FTPContent',['../servicecom_1_1sun_1_1star_1_1ucb_1_1FTPContent.html',1,'com::sun::star::ucb']]],
-  ['ftpcontentprovider_76',['FTPContentProvider',['../servicecom_1_1sun_1_1star_1_1ucb_1_1FTPContentProvider.html',1,'com::sun::star::ucb']]],
-  ['function_77',['Function',['../servicecom_1_1sun_1_1star_1_1report_1_1Function.html',1,'com::sun::star::report']]],
-  ['functionaccess_78',['FunctionAccess',['../servicecom_1_1sun_1_1star_1_1sheet_1_1FunctionAccess.html',1,'com::sun::star::sheet']]],
-  ['functionargument_79',['FunctionArgument',['../structcom_1_1sun_1_1star_1_1sheet_1_1FunctionArgument.html',1,'com::sun::star::sheet']]],
-  ['functiondescription_80',['FunctionDescription',['../servicecom_1_1sun_1_1star_1_1sheet_1_1FunctionDescription.html',1,'com::sun::star::sheet']]],
-  ['functiondescriptionenumeration_81',['FunctionDescriptionEnumeration',['../servicecom_1_1sun_1_1star_1_1sheet_1_1FunctionDescriptionEnumeration.html',1,'com::sun::star::sheet']]],
-  ['functiondescriptions_82',['FunctionDescriptions',['../servicecom_1_1sun_1_1star_1_1sheet_1_1FunctionDescriptions.html',1,'com::sun::star::sheet']]]
+  ['fontsdisalloweditingrequest_45',['FontsDisallowEditingRequest',['../exceptioncom_1_1sun_1_1star_1_1document_1_1FontsDisallowEditingRequest.html',1,'com::sun::star::document']]],
+  ['footer_46',['Footer',['../servicecom_1_1sun_1_1star_1_1presentation_1_1textfield_1_1Footer.html',1,'com::sun::star::presentation::textfield']]],
+  ['footershape_47',['FooterShape',['../servicecom_1_1sun_1_1star_1_1presentation_1_1FooterShape.html',1,'com::sun::star::presentation']]],
+  ['footnote_48',['Footnote',['../servicecom_1_1sun_1_1star_1_1text_1_1Footnote.html',1,'com::sun::star::text']]],
+  ['footnotes_49',['Footnotes',['../servicecom_1_1sun_1_1star_1_1text_1_1Footnotes.html',1,'com::sun::star::text']]],
+  ['footnotesettings_50',['FootnoteSettings',['../servicecom_1_1sun_1_1star_1_1text_1_1FootnoteSettings.html',1,'com::sun::star::text']]],
+  ['forbiddencharacters_51',['ForbiddenCharacters',['../structcom_1_1sun_1_1star_1_1i18n_1_1ForbiddenCharacters.html',1,'com::sun::star::i18n']]],
+  ['form_52',['Form',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1Form.html',1,'com::sun::star::form::component']]],
+  ['formatcondition_53',['FormatCondition',['../servicecom_1_1sun_1_1star_1_1report_1_1FormatCondition.html',1,'com::sun::star::report']]],
+  ['formatelement_54',['FormatElement',['../structcom_1_1sun_1_1star_1_1i18n_1_1FormatElement.html',1,'com::sun::star::i18n']]],
+  ['formattedfield_55',['FormattedField',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1FormattedField.html',1,'FormattedField'],['../servicecom_1_1sun_1_1star_1_1form_1_1control_1_1FormattedField.html',1,'FormattedField'],['../servicecom_1_1sun_1_1star_1_1report_1_1FormattedField.html',1,'FormattedField']]],
+  ['formattedstring_56',['FormattedString',['../servicecom_1_1sun_1_1star_1_1chart2_1_1FormattedString.html',1,'com::sun::star::chart2']]],
+  ['formcomponent_57',['FormComponent',['../servicecom_1_1sun_1_1star_1_1form_1_1FormComponent.html',1,'com::sun::star::form']]],
+  ['formcomponentpropertyhandler_58',['FormComponentPropertyHandler',['../servicecom_1_1sun_1_1star_1_1form_1_1inspection_1_1FormComponentPropertyHandler.html',1,'com::sun::star::form::inspection']]],
+  ['formcomponents_59',['FormComponents',['../servicecom_1_1sun_1_1star_1_1form_1_1FormComponents.html',1,'com::sun::star::form']]],
+  ['formcontroller_60',['FormController',['../servicecom_1_1sun_1_1star_1_1form_1_1FormController.html',1,'FormController'],['../servicecom_1_1sun_1_1star_1_1form_1_1runtime_1_1FormController.html',1,'FormController']]],
+  ['formcontrollerdispatcher_61',['FormControllerDispatcher',['../servicecom_1_1sun_1_1star_1_1form_1_1FormControllerDispatcher.html',1,'com::sun::star::form']]],
+  ['formcontrolmodel_62',['FormControlModel',['../servicecom_1_1sun_1_1star_1_1form_1_1FormControlModel.html',1,'com::sun::star::form']]],
+  ['formoperations_63',['FormOperations',['../servicecom_1_1sun_1_1star_1_1form_1_1runtime_1_1FormOperations.html',1,'com::sun::star::form::runtime']]],
+  ['forms_64',['Forms',['../servicecom_1_1sun_1_1star_1_1form_1_1Forms.html',1,'Forms'],['../servicecom_1_1sun_1_1star_1_1sdb_1_1Forms.html',1,'Forms']]],
+  ['formulaopcodemapentry_65',['FormulaOpCodeMapEntry',['../structcom_1_1sun_1_1star_1_1sheet_1_1FormulaOpCodeMapEntry.html',1,'com::sun::star::sheet']]],
+  ['formulaopcodemapper_66',['FormulaOpCodeMapper',['../servicecom_1_1sun_1_1star_1_1sheet_1_1FormulaOpCodeMapper.html',1,'com::sun::star::sheet']]],
+  ['formulaparser_67',['FormulaParser',['../servicecom_1_1sun_1_1star_1_1sheet_1_1FormulaParser.html',1,'com::sun::star::sheet']]],
+  ['formulaproperties_68',['FormulaProperties',['../servicecom_1_1sun_1_1star_1_1formula_1_1FormulaProperties.html',1,'com::sun::star::formula']]],
+  ['formulatoken_69',['FormulaToken',['../structcom_1_1sun_1_1star_1_1sheet_1_1FormulaToken.html',1,'com::sun::star::sheet']]],
+  ['frame_70',['Frame',['../servicecom_1_1sun_1_1star_1_1frame_1_1Frame.html',1,'com::sun::star::frame']]],
+  ['frameactionevent_71',['FrameActionEvent',['../structcom_1_1sun_1_1star_1_1frame_1_1FrameActionEvent.html',1,'com::sun::star::frame']]],
+  ['framecontrol_72',['FrameControl',['../servicecom_1_1sun_1_1star_1_1frame_1_1FrameControl.html',1,'com::sun::star::frame']]],
+  ['frameloader_73',['FrameLoader',['../servicecom_1_1sun_1_1star_1_1frame_1_1FrameLoader.html',1,'com::sun::star::frame']]],
+  ['frameloaderfactory_74',['FrameLoaderFactory',['../servicecom_1_1sun_1_1star_1_1frame_1_1FrameLoaderFactory.html',1,'com::sun::star::frame']]],
+  ['framescontainer_75',['FramesContainer',['../servicecom_1_1sun_1_1star_1_1frame_1_1FramesContainer.html',1,'com::sun::star::frame']]],
+  ['ftpcontent_76',['FTPContent',['../servicecom_1_1sun_1_1star_1_1ucb_1_1FTPContent.html',1,'com::sun::star::ucb']]],
+  ['ftpcontentprovider_77',['FTPContentProvider',['../servicecom_1_1sun_1_1star_1_1ucb_1_1FTPContentProvider.html',1,'com::sun::star::ucb']]],
+  ['function_78',['Function',['../servicecom_1_1sun_1_1star_1_1report_1_1Function.html',1,'com::sun::star::report']]],
+  ['functionaccess_79',['FunctionAccess',['../servicecom_1_1sun_1_1star_1_1sheet_1_1FunctionAccess.html',1,'com::sun::star::sheet']]],
+  ['functionargument_80',['FunctionArgument',['../structcom_1_1sun_1_1star_1_1sheet_1_1FunctionArgument.html',1,'com::sun::star::sheet']]],
+  ['functiondescription_81',['FunctionDescription',['../servicecom_1_1sun_1_1star_1_1sheet_1_1FunctionDescription.html',1,'com::sun::star::sheet']]],
+  ['functiondescriptionenumeration_82',['FunctionDescriptionEnumeration',['../servicecom_1_1sun_1_1star_1_1sheet_1_1FunctionDescriptionEnumeration.html',1,'com::sun::star::sheet']]],
+  ['functiondescriptions_83',['FunctionDescriptions',['../servicecom_1_1sun_1_1star_1_1sheet_1_1FunctionDescriptions.html',1,'com::sun::star::sheet']]]
 ];
